@@ -1,6 +1,7 @@
 from nats.aio.client import Client as NATS
 import json
 import os
+import asyncio
 import logging
 from sentry_sdk import capture_exception
 
@@ -23,10 +24,9 @@ class NeoNatsClient(NATS):
             f"nats://{self.npq_host}:{self.npq_port}",
             user=self.npq_user,
             password=self.npq_pass,
-            loop=loop,
+            io_loop=loop,
         )
-        self.logger.info(
-            f"Connected to nats://{self.npq_host}:{self.npq_port}")
+        self.logger.info(f"Connected to nats://{self.npq_host}:{self.npq_port}")
 
     async def process(self, queue, processor):
         async def process_handler(msg):
